@@ -32,14 +32,13 @@
 
 using System;
 using System.Collections;
-using System.Diagnostics;
 using System.IO;
 using System.Net.Sockets;
 using System.Runtime.InteropServices;
-using System.Runtime.CompilerServices;
 using System.Text;
-using System.Threading;
 using System.Collections.Generic;
+using Mono.WebServer.Apache;
+using Mono.WebServer.Log;
 
 namespace Mono.WebServer
 {
@@ -49,13 +48,13 @@ namespace Mono.WebServer
 		const int INITIAL_MEMORY_STREAM_SIZE = 1024 * 2;
 		const int MAX_MEMORY_STREAM_SIZE = 1024 * 128;
 		
-		BinaryReader reader;
-		BinaryWriter writer;
-		MemoryStream reader_ms;
-		MemoryStream writer_ms;
+		readonly BinaryReader reader;
+		readonly BinaryWriter writer;
+		readonly MemoryStream reader_ms;
+		readonly MemoryStream writer_ms;
 		byte[] fill_buffer;
 		bool got_server_vars;
-		Dictionary <string, string> serverVariables;
+		readonly Dictionary <string, string> serverVariables;
 		string verb;
 		string queryString;
 		string protocol;
@@ -70,13 +69,15 @@ namespace Mono.WebServer
 		bool setupClientBlockCalled;
 		Dictionary <string, string> headers;
 		int clientBlock;
-		bool shutdown;
 		StringBuilder out_headers = new StringBuilder ();
-		bool headers_sent;
 		string physical_path;
 		ModMonoConfig mod_mono_config;
-		Socket client;
-		static bool use_libc;
+		readonly Socket client;
+		readonly static bool use_libc;
+
+		public bool HeadersSent { get; private set; }
+
+		public bool ShuttingDown { get; private set; }
 
 		static ModMonoRequest ()
 		{
@@ -84,9 +85,7 @@ namespace Mono.WebServer
 				return;
 
 			try {
-				string os = "";
-				using (StreamReader sr = new StreamReader (File.OpenRead ("/proc/sys/kernel/ostype")))
-					os = sr.ReadToEnd ();
+				string os = File.ReadAllText ("/proc/sys/kernel/ostype");
 				use_libc = os.StartsWith ("Linux");
 			} catch {
 			}
@@ -104,15 +103,7 @@ namespace Mono.WebServer
 			GetInitialData ();
 		}
 
-		public bool HeadersSent {
-			get { return headers_sent; }
-		}
-
-		public bool ShuttingDown {
-			get { return shutdown; }
-		}
-
-		void Dispose (Action disposer, string name)
+		static void Dispose (Action disposer, string name)
 		{
 			if (disposer == null)
 				return;
@@ -120,8 +111,8 @@ namespace Mono.WebServer
 			try {
 				disposer ();
 			} catch (Exception ex) {
-				Console.Error.WriteLine ("While disposing ModMonoRequest. {0} disposing failed with exception:", name);
-				Console.Error.WriteLine (ex);
+				Logger.Write (LogLevel.Error, "While disposing ModMonoRequest. {0} disposing failed with exception:", name);
+				Logger.Write (ex);
 			}
 		}
 		
@@ -165,7 +156,7 @@ namespace Mono.WebServer
 			reader_ms.SetLength (0);
 			reader_ms.Position = 0;
 
-			int read_count = (int)count;
+			var read_count = (int)count;
 			int fill_buffer_length = fill_buffer == null ? 0 : fill_buffer.Length;
 			if ((uint)fill_buffer_length < count) {
 				if (fill_buffer == null && count <= INITIAL_MEMORY_STREAM_SIZE) {
@@ -191,28 +182,29 @@ namespace Mono.WebServer
 
 		void Send ()
 		{
-			client.Send (writer_ms.GetBuffer (), (int) writer_ms.Length, SocketFlags.None);
+			int sent = client.Send (writer_ms.GetBuffer (), (int) writer_ms.Length, SocketFlags.None);
+			if (sent != (int) writer_ms.Length)
+				throw new IOException ("Blocking send did not send entire buffer");
 			writer_ms.Position = 0;
 			writer_ms.SetLength (0);
 		}
 
 		// KEEP IN SYNC WITH mod_mono.h!!
-		const byte protocol_version = 9;
+		const byte PROTOCOL_VERSION = 9;
 		void GetInitialData ()
 		{
 			FillBuffer (5);
 			
 			byte cmd = reader.ReadByte ();
-			shutdown = (cmd == 0);
-			if (shutdown) {
-				Console.Error.WriteLine ("mod-mono-server received a shutdown message");
+			ShuttingDown = (cmd == 0);
+			if (ShuttingDown) {
+				Logger.Write (LogLevel.Notice, "mod-mono-server received a shutdown message");
 				return;
 			}
 
-			if (cmd != protocol_version) {
-				string msg = String.Format ("mod_mono and xsp have different versions. Expected '{0}', got {1}", protocol_version, cmd);
-				Console.WriteLine (msg);
-				Console.Error.WriteLine (msg);
+			if (cmd != PROTOCOL_VERSION) {
+				string msg = String.Format ("mod_mono and xsp have different versions. Expected '{0}', got {1}", PROTOCOL_VERSION, cmd);
+				Logger.Write (LogLevel.Error, msg);
 				throw new InvalidOperationException (msg);
 			}
 
@@ -239,7 +231,7 @@ namespace Mono.WebServer
 					continue;
 				
 				if (headers.ContainsKey (key)) {
-					Console.WriteLine ("WARNING: duplicate header '{0}' found! Overwriting old value with the new one.", key);
+					Logger.Write (LogLevel.Warning, "Duplicate header '{0}' found! Overwriting old value with the new one.", key);
 					headers [key] = ReadString ();
 				} else
 					headers.Add (key, ReadString ());
@@ -255,24 +247,19 @@ namespace Mono.WebServer
 			if (size < 0 || size > MAX_STRING_SIZE)
 				throw new ArgumentOutOfRangeException ("size", "Abnormal string size " + size);
 
-			byte [] buf = new byte [size];
-			string s;
-			if (size != 0) {
-				int chunk;
-				int total = 0;
-				do {
-					chunk = reader.Read (buf, total, size - total);
-					if (chunk == 0)
-						throw new IOException ("Lost connection with mod_mono");
-					if (chunk > 0)
-						total += chunk;
-				} while ((chunk > 0 && total < size));
-
-				s = Encoding.UTF8.GetString (buf);
-			} else {
-				s = "";
-			}
-			return s;
+			var buf = new byte [size];
+			if (size == 0)
+				return String.Empty;
+			int chunk;
+			int total = 0;
+			do {
+				chunk = reader.Read (buf, total, size - total);
+				if (chunk == 0)
+					throw new IOException ("Lost connection with mod_mono");
+				if (chunk > 0)
+					total += chunk;
+			} while ((chunk > 0 && total < size));
+			return Encoding.UTF8.GetString (buf);
 		}
 
 		void WriteString (string s)
@@ -312,7 +299,9 @@ namespace Mono.WebServer
 			writer.Write (length);
 			Send ();
 			if (use_libc) {
-				Send (ptr, length);
+				int sent = Send (ptr, length);
+				if (sent != length)
+					throw new IOException ("Blocking send did not send entire buffer");
 				return;
 			}
 			
@@ -328,17 +317,20 @@ namespace Mono.WebServer
 				Marshal.Copy (ptr, buf, 0, size);
 				length -= size;
 				unsafe { ptr = (IntPtr)((byte*)ptr.ToPointer () + size); }
-				client.Send (buf, size, SocketFlags.None);
+				int sent = client.Send (buf, size, SocketFlags.None);
+				if (sent != size)
+					throw new IOException ("Blocking send did not send entire buffer");
 			}
 		}
 
+		// FIXME: the return value is never used
 		unsafe int Send (IntPtr ptr, int len)
 		{
 			int total = 0;
-			byte *bptr = (byte *) ptr.ToPointer ();
+			var bptr = (byte *) ptr.ToPointer ();
 			while (total < len) {
 				// 0x4000 no sigpipe
-				int n = send_libc (client.Handle.ToInt32 (), bptr + total, (IntPtr) (len - total), (int) 0x4000);
+				int n = send_libc (client.Handle.ToInt32 (), bptr + total, (IntPtr) (len - total), 0x4000);
 				if (n >= 0) {
 					total += n;
 				} else if (Marshal.GetLastWin32Error () != 4 /* EINTR */) {
@@ -359,7 +351,9 @@ namespace Mono.WebServer
 			writer.Write ((int) ModMonoCmd.SEND_FROM_MEMORY);
 			writer.Write (length);
 			Send ();
-			client.Send (data, position, length, SocketFlags.None);
+			int sent = client.Send (data, position, length, SocketFlags.None);
+			if (sent != length)
+				throw new IOException ("Blocking send did not send entire buffer");
 		}
 
 		public void SendFile (string filename)
@@ -383,18 +377,18 @@ namespace Mono.WebServer
 		
 		void BufferHeaders ()
 		{
-			if (headers_sent)
+			if (HeadersSent)
 				return;
 
 			writer.Write ((int) ModMonoCmd.SET_RESPONSE_HEADERS);
 			WriteString (out_headers.ToString ());
 			out_headers = null;
-			headers_sent = true;
+			HeadersSent = true;
 		}
 
 		public void SetResponseHeader (string name, string value)
 		{
-			if (!headers_sent)
+			if (!HeadersSent)
 				out_headers.AppendFormat ("{0}\0{1}\0", name, value);
 		}
 
@@ -406,7 +400,7 @@ namespace Mono.WebServer
 		public string [] GetAllHeaders ()
 		{
 			ICollection k = headers.Keys;
-			string [] keys = new string [k.Count];
+			var keys = new string [k.Count];
 			k.CopyTo (keys, 0);
 			return keys;
 		}
@@ -414,7 +408,7 @@ namespace Mono.WebServer
 		public string [] GetAllHeaderValues ()
 		{
 			ICollection v = headers.Values;
-			string [] values = new string [v.Count];
+			var values = new string [v.Count];
 			v.CopyTo (values, 0);
 			return values;
 		}
@@ -422,7 +416,7 @@ namespace Mono.WebServer
 		public string GetRequestHeader (string name)
 		{
 			if (headers.ContainsKey (name))
-				return headers [name] as string;
+				return headers [name];
 			return null;
 		}
 
@@ -443,7 +437,7 @@ namespace Mono.WebServer
 					continue;
 				
 				if (serverVariables.ContainsKey (key)) {
-					Console.WriteLine ("WARNING! Duplicate server variable '{0}' found. Overwriting old value with the new one.", key);
+					Logger.Write(LogLevel.Warning, "Duplicate server variable '{0}' found. Overwriting old value with the new one.", key);
 					serverVariables [key] = ReadString ();
 				} else
 					serverVariables.Add (key, ReadString ());
@@ -458,7 +452,7 @@ namespace Mono.WebServer
 				GetServerVariables ();
 
 			if (serverVariables.ContainsKey (name))
-				return (string) serverVariables [name];
+				return serverVariables [name];
 
 			return null;
 		}
