@@ -29,8 +29,6 @@
 
 using System;
 using System.Collections.Generic;
-using Mono.FastCgi;
-using Mono.WebServer;
 using System.Text;
 using System.Net;
 using System.Globalization;
@@ -40,7 +38,7 @@ namespace Mono.WebServer.FastCgi
 {
 	public class WorkerRequest : MonoWorkerRequest
 	{
-		private static string [] indexFiles = { "index.aspx",
+		static string [] indexFiles = { "index.aspx",
 							"default.aspx",
 							"index.html",
 							"index.htm" };
@@ -50,16 +48,16 @@ namespace Mono.WebServer.FastCgi
 			SetDefaultIndexFiles (System.Configuration.ConfigurationManager.AppSettings ["MonoServerDefaultIndexFiles"]);
 		}
 		
-		private StringBuilder headers = new StringBuilder ();
-		private Responder responder;
-		private byte [] input_data;
-		private string file_path;
-		string raw_url = null;
-		private bool closed = false;
-		string uri_path = null;
-		private string [][] unknownHeaders = null;
-		private string [] knownHeaders = null;
-		string path_info;
+		StringBuilder headers = new StringBuilder ();
+		readonly Responder responder;
+		readonly byte [] input_data;
+		string file_path;
+		string raw_url;
+		bool closed;
+		string uri_path;
+		string [][] unknownHeaders;
+		string [] knownHeaders;
+		readonly string path_info;
 
 		public WorkerRequest (Responder responder, ApplicationHost appHost) : base (appHost)
 		{
@@ -102,7 +100,7 @@ namespace Mono.WebServer.FastCgi
 				return;
 			
 			closed = true;
-			this.EnsureHeadersSent ();
+			EnsureHeadersSent ();
 			responder.CompleteRequest (0);
 		}
 		public override void SendResponseFromMemory (byte [] data, int length)
@@ -158,14 +156,14 @@ namespace Mono.WebServer.FastCgi
 				return raw_url;
 			}
 			
-			StringBuilder b = new StringBuilder (GetUriPath ());
+			var builder = new StringBuilder (GetUriPath ());
 			string query = GetQueryString ();
-			if (query != null && query.Length > 0) {
-				b.Append ('?');
-				b.Append (query);
+			if (!String.IsNullOrEmpty(query)) {
+				builder.Append ('?');
+				builder.Append (query);
 			}
 			
-			raw_url = b.ToString ();
+			raw_url = builder.ToString ();
 			return raw_url;
 		}
 
@@ -190,17 +188,17 @@ namespace Mono.WebServer.FastCgi
 		public override string GetLocalAddress ()
 		{
 			string address = responder.GetParameter ("SERVER_ADDR");
-			if (address != null && address.Length > 0)
+			if (!String.IsNullOrEmpty(address))
 				return address;
 			
 			address = AddressFromHostName (
 				responder.GetParameter ("HTTP_HOST"));
-			if (address != null && address.Length > 0)
+			if (!String.IsNullOrEmpty(address))
 				return address;
 			
 			address = AddressFromHostName (
 				responder.GetParameter ("SERVER_NAME"));
-			if (address != null && address.Length > 0)
+			if (!String.IsNullOrEmpty(address))
 				return address;
 			
 			return base.GetLocalAddress ();
@@ -231,14 +229,14 @@ namespace Mono.WebServer.FastCgi
 		public override string GetRemoteAddress ()
 		{
 			string addr = responder.GetParameter ("REMOTE_ADDR");
-			return addr != null && addr.Length > 0 ?
+			return !String.IsNullOrEmpty(addr) ?
 				addr : base.GetRemoteAddress ();
 		}
 		
 		public override string GetRemoteName ()
 		{
 			string ip = GetRemoteAddress ();
-			string name = null;
+			string name;
 			try {
 				IPHostEntry entry = Dns.GetHostEntry (ip);
 				name = entry.HostName;
@@ -252,24 +250,20 @@ namespace Mono.WebServer.FastCgi
 		public override int GetRemotePort ()
 		{
 			string port = responder.GetParameter ("REMOTE_PORT");
-			if (port == null || port.Length == 0)
+			if (String.IsNullOrEmpty(port))
 				return base.GetRemotePort ();
 			
-			try {
-				return int.Parse (port);
-			} catch {
-				return base.GetRemotePort ();
-			}
+			int ret;
+			if (Int32.TryParse (port, out ret))
+				return ret;
+			return base.GetRemotePort ();
 		}
 		
 		public override string GetServerVariable (string name)
 		{
-			string value = responder.GetParameter (name);
-			
-			if (value == null)
-				value = Environment.GetEnvironmentVariable (name);
-			
-			return value != null ? value : base.GetServerVariable (name);
+			return (responder.GetParameter (name)
+				?? Environment.GetEnvironmentVariable (name))
+				?? base.GetServerVariable (name);
 		}
 		
 
@@ -296,7 +290,7 @@ namespace Mono.WebServer.FastCgi
 			
 			string path = responder.PhysicalPath;
 			
-			DirectoryInfo dir = new DirectoryInfo (path);
+			var dir = new DirectoryInfo (path);
 			
 			if (!dir.Exists)
 				return file_path;
@@ -337,7 +331,7 @@ namespace Mono.WebServer.FastCgi
 			
 			IDictionary<string,string> pairs = responder.GetParameters ();
 			knownHeaders = new string [RequestHeaderMaximum];
-			string [][] headers = new string [pairs.Count][];
+			var headers = new string [pairs.Count][];
 			int count = 0;
 			
 			foreach (string key in pairs.Keys) {
@@ -345,7 +339,7 @@ namespace Mono.WebServer.FastCgi
 					continue;
 				
 				string name  = ReformatHttpHeader (key);
-				string value = (string) pairs [key];
+				string value = pairs [key];
 				int id = GetKnownRequestHeaderIndex (name);
 				
 				if (id >= 0) {
@@ -353,25 +347,25 @@ namespace Mono.WebServer.FastCgi
 					continue;
 				}
 				
-				headers [count++] = new string [] {name, value};
+				headers [count++] = new[] {name, value};
 			}
 			
 			unknownHeaders = new string [count][];
-			System.Array.Copy (headers, 0, unknownHeaders, 0, count);
+			Array.Copy (headers, 0, unknownHeaders, 0, count);
 			
 			return unknownHeaders;
 		}
 		
 		public override string GetKnownRequestHeader (int index)
 		{
-			string value = null;
+			string value;
 			switch (index)
 			{
-			case System.Web.HttpWorkerRequest.HeaderContentType:
+			case HeaderContentType:
 				value = responder.GetParameter ("CONTENT_TYPE");
 				break;
 				
-			case System.Web.HttpWorkerRequest.HeaderContentLength:
+			case HeaderContentLength:
 				value = responder.GetParameter ("CONTENT_LENGTH");
 				break;
 			default:
@@ -380,23 +374,14 @@ namespace Mono.WebServer.FastCgi
 				break;
 			}
 			
-			return (value != null) ?
-				value : base.GetKnownRequestHeader (index);
+			return value ?? base.GetKnownRequestHeader (index);
 		}
 		
 		public override string GetServerName ()
 		{
-			string server_name = HostNameFromString (
-				responder.GetParameter ("SERVER_NAME"));
-			
-			if (server_name == null)
-				server_name = HostNameFromString (
-					responder.GetParameter ("HTTP_HOST"));
-			
-			if (server_name == null)
-				server_name = GetLocalAddress ();
-			
-			return server_name;
+			return (HostNameFromString (responder.GetParameter ("SERVER_NAME"))
+				?? HostNameFromString (responder.GetParameter ("HTTP_HOST")))
+				?? GetLocalAddress ();
 		}
 
 		public override byte [] GetPreloadedEntityBody ()
@@ -410,7 +395,7 @@ namespace Mono.WebServer.FastCgi
 		
 		#region Private Methods
 		
-		private void AppendHeaderLine (string format, params object [] args)
+		void AppendHeaderLine (string format, params object [] args)
 		{
 			if (headers == null)
 				return;
@@ -420,29 +405,29 @@ namespace Mono.WebServer.FastCgi
 			headers.Append ("\r\n");
 		}
 		
-		private void EnsureHeadersSent ()
+		void EnsureHeadersSent ()
 		{
-			if (headers != null) {
-				headers.Append ("\r\n");
-				string str = headers.ToString ();
-				responder.SendOutput (str,
-					HeaderEncoding);
-				headers = null;
-			}
+			if (headers == null)
+				return;
+
+			headers.Append ("\r\n");
+			string str = headers.ToString ();
+			responder.SendOutput (str, HeaderEncoding);
+			headers = null;
 		}
 		
 		#endregion
 		
 		#region Private Static Methods
 		
-		private static string AddressFromHostName (string host)
+		static string AddressFromHostName (string host)
 		{
 			host = HostNameFromString (host);
 			
 			if (host == null || host.Length > 126)
 				return null;
 			
-			System.Net.IPAddress [] addresses = null;
+			IPAddress [] addresses;
 			try {
 				addresses = Dns.GetHostAddresses (host);
 			} catch (System.Net.Sockets.SocketException) {
@@ -457,9 +442,9 @@ namespace Mono.WebServer.FastCgi
 			return addresses [0].ToString ();
 		}
 		
-		private static string HostNameFromString (string host)
+		static string HostNameFromString (string host)
 		{
-			if (host == null || host.Length == 0)
+			if (String.IsNullOrEmpty(host))
 				return null;
 			
 			int colon_index = host.IndexOf (':');
@@ -473,13 +458,13 @@ namespace Mono.WebServer.FastCgi
 			return host.Substring (0, colon_index);
 		}
 		
-		private static string ReformatHttpHeader (string header)
+		static string ReformatHttpHeader (string header)
 		{
 			string [] parts = header.Substring (5).Split ('_');
 			for (int i = 0; i < parts.Length; i ++) {
 				string s = parts [i];
 				if (String.IsNullOrEmpty (s)) {
-					parts [i] = "";
+					parts [i] = String.Empty;
 					continue;
 				}
 
@@ -489,26 +474,15 @@ namespace Mono.WebServer.FastCgi
 				parts [i] = new String (a);
 			}
 			
-			return string.Join ("-", parts);
+			return String.Join ("-", parts);
 		}
 
-		private static void SetDefaultIndexFiles (string list)
+		static void SetDefaultIndexFiles (string list)
 		{
 			if (list == null)
 				return;
-			
-			List<string> files = new List<string> ();
-			
-			string [] fs = list.Split (',');
-			foreach (string f in fs) {
-				string trimmed = f.Trim ();
-				if (trimmed == "") 
-					continue;
 
-				files.Add (trimmed);
-			}
-
-			indexFiles = files.ToArray ();
+			indexFiles = SplitAndTrim (list);
 		}
 		
 		#endregion
