@@ -29,7 +29,6 @@
 
 
 using System;
-using System.Collections;
 
 namespace Mono.WebServer
 {
@@ -48,7 +47,7 @@ namespace Mono.WebServer
 		
 		// Contains a lock to use when accessing and modifying the
 		// request allocation tables.
-		static object reqlock = new object();		
+		static readonly object reqlock = new object();
 
 		// Contains the request ID's.
 		int[] request_ids = new int [INITIAL_REQUESTS];
@@ -60,26 +59,25 @@ namespace Mono.WebServer
 		byte[][] buffers = new byte [INITIAL_REQUESTS][];
 		
 		// Contains the number of active requests.
-		int requests_count = 0;
+		int requests_count;
 
 		// Contains the total number of requests served so far.
 		// May freely wrap around.
-		uint requests_served = 0;
+		uint requests_served;
 
-		// Grows the size of the request allocation tables by 33%.
-		//
-		// Parameters:
-		//   curlen - current length of the allocation tables.
-		//   newid - ID to use for a new request.
-		//
-		// This *MUST* be called with the reqlock held!
-		//
-		void GrowRequests (ref int curlen, ref int newid)
+		/// <summary>
+		/// Grows the size of the request allocation tables by 33%.
+		///
+		/// This *MUST* be called with the reqlock held!
+		/// </summary>
+		/// <returns>ID to use for a new request.</returns>
+		/// <param name="curlen">Current length of the allocation tables.</param>
+		int GrowRequests (ref int curlen)
 		{
 			int newsize = curlen + curlen/3;
-			int[] new_request_ids = new int [newsize];
-			Worker[] new_requests = new Worker [newsize];
-			byte[][] new_buffers = new byte [newsize][];
+			var new_request_ids = new int [newsize];
+			var new_requests = new Worker [newsize];
+			var new_buffers = new byte [newsize][];
 
 			request_ids.CopyTo (new_request_ids, 0);
 			Array.Clear (request_ids, 0, request_ids.Length);
@@ -93,59 +91,54 @@ namespace Mono.WebServer
 			Array.Clear (buffers, 0, buffers.Length);
 			buffers = new_buffers;
 
-			newid = curlen + 1;
 			curlen = newsize;
+			return curlen + 1;
 		}
 		
-		// Gets the next available request ID, expanding the array
-		// of possible ID's if necessary.
-		//
-		// Returns ID of the request.
-		//
-		// This *MUST* be called with the reqlock held!
-		//
+		/// <summary>
+		/// Gets the next available request ID, expanding the array
+		/// of possible ID's if necessary.
+		///
+		/// This *MUST* be called with the reqlock held!
+		/// </summary>
+		/// <returns>ID of the request.</returns>
 		int GetNextRequestId ()
 		{
 			int reqlen = request_ids.Length;
-			int newid = -1;
-			
+
 			requests_served++; // increment to 1 before putting into request_ids
 					   // so that the 0 id is reserved for slot not used
 			if (requests_served == 0x8000) // and check for wrap-around for the above
 				requests_served = 1; // making sure we don't exceed 0x7FFF or go negative
 
 			requests_count++;
+
+			int newid;
 			if (requests_count >= reqlen)
-				GrowRequests (ref reqlen, ref newid);
-			if (newid == -1)
-				for (int i = 0; i < reqlen; i++) {
-					if (request_ids [i] == 0) {
-						newid = i;
-						break;
-					}
+				newid = GrowRequests (ref reqlen);
+			else
+				newid = Array.IndexOf (request_ids, 0);
+
+			if (newid == -1) {
+				// Should never happen...
+				throw new ApplicationException ("could not allocate new request id");
 			}
 
-			if (newid != -1) {
-				// TODO: newid had better not exceed 0xFFFF.
-				newid = (int)(((ushort)newid & 0xFFFF) | (((ushort)requests_served & 0x7FFF) << 16));
-				request_ids [IdToIndex(newid)] = newid;
-				return newid;
-			}
-				
-			// Should never happen...
-			throw new ApplicationException ("could not allocate new request id");
+			// TODO: newid had better not exceed 0xFFFF.
+			newid = ((ushort)newid & 0xFFFF) | (((ushort)requests_served & 0x7FFF) << 16);
+			request_ids [IdToIndex(newid)] = newid;
+			return newid;
 		}		
 
 		public int RegisterRequest (Worker worker)
 		{
-			int result = -1;
+			int result;
 			
 			lock (reqlock) {
 				result = IdToIndex (GetNextRequestId ());
 				requests [result] = worker;
 				
-				// Don't create a new array if one already
-				// exists.
+				// Don't create a new array if one already exists.
 				byte[] a = buffers [result];
 				if (a == null)
 					buffers [result] = new byte [BUFFER_SIZE];
@@ -154,7 +147,7 @@ namespace Mono.WebServer
 			return request_ids [result];
 		}
 
-		private int IdToIndex(int requestId) {
+		int IdToIndex(int requestId) {
 			return requestId & 0xFFFF;
 		}
 
@@ -175,14 +168,13 @@ namespace Mono.WebServer
 				requests_count--;
 			}
 		}
-		
-		// Invokes registered handlers of UnregisterRequestEvent. Each handler is passed an
-		// arguments object which contains the ID of a request that is about to be
-		// unregistered.
-		//
-		// Parameters:
-		//   id - ID of a request that is about to be unregistered
-		//
+
+		/// <summary>
+		/// Invokes registered handlers of UnregisterRequestEvent. Each handler is passed an
+		/// arguments object which contains the ID of a request that is about to be
+		/// unregistered.
+		/// </summary>
+		/// <param name="id">ID of a request that is about to be unregistered.</param>
 		void DoUnregisterRequest (int id)
 		{
 			if (UnregisterRequestEvent == null)
@@ -191,7 +183,7 @@ namespace Mono.WebServer
 			if (handlers == null || handlers.Length == 0)
 				return;
 			
-			UnregisterRequestEventArgs args = new UnregisterRequestEventArgs (id);
+			var args = new UnregisterRequestEventArgs (id);
 			foreach (UnregisterRequestEventHandler handler in handlers)
 				handler (this, args);
 		}		
@@ -217,9 +209,9 @@ namespace Mono.WebServer
 				if (w == null)
 					return 0;
 
-				//use a pre-allocated buffer only when the size matches
-				//as it will be transferred across appdomain boundaries
-				//in full length
+				// Use a pre-allocated buffer only when the size matches
+				// as it will be transferred across appdomain boundaries
+				// in full length
 				if (size == BUFFER_SIZE) {
 					buffer = buffers [IdToIndex (requestId)];
 				} else {
@@ -236,7 +228,7 @@ namespace Mono.WebServer
 				if (!ValidRequest (requestId))
 					return null;
 			
-				return (Worker) requests [IdToIndex (requestId)];
+				return requests [IdToIndex (requestId)];
 			}
 		}
 
@@ -274,4 +266,3 @@ namespace Mono.WebServer
 		}
 	}
 }
-
