@@ -27,11 +27,8 @@
 // WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 //
 using System;
-using System.Collections;
-using System.Configuration;
+using System.Collections.Generic;
 using System.IO;
-using System.Net;
-using System.Net.Sockets;
 using System.Text;
 using System.Web;
 
@@ -43,24 +40,36 @@ namespace Mono.WebServer
 		string path;
 		string queryString;
 		string protocol;
-		Stream stream;
-		bool gotSomeInput;
+		readonly Stream stream;
 
-		byte [] inputBuffer;
 		int inputLength;
 		int position;
-		const int BSize = 1024 * 32;
+		const int B_SIZE = 1024 * 32;
 		
-		static Stack bufferStack = new Stack ();
-		static Encoding encoding = Encoding.GetEncoding (28591);
+		static readonly Stack<byte[]> bufferStack = new Stack<byte[]> ();
+		static readonly Encoding encoding = Encoding.GetEncoding (28591);
+
+		public bool GotSomeInput { get; private set; }
+
+		public byte [] InputBuffer { get; private set; }
+
+		public RequestData RequestData {
+			get {
+				var rd = new RequestData (verb, path, queryString, protocol);
+				var buffer = new byte [inputLength - position];
+				Buffer.BlockCopy (InputBuffer, position, buffer, 0, inputLength - position);
+				rd.InputBuffer = buffer;
+				return rd;
+			}
+		}
 		
 		public static byte [] AllocateBuffer ()
 		{
 			lock (bufferStack) {
 				if (bufferStack.Count != 0)
-					return (byte []) bufferStack.Pop ();
+					return bufferStack.Pop ();
 			}
-			return new byte [BSize];
+			return new byte [B_SIZE];
 		}
 		
 		public static void FreeBuffer (byte [] buf)
@@ -83,51 +92,51 @@ namespace Mono.WebServer
 
 		public void FreeBuffer ()
 		{
-			if (inputBuffer != null)
-				FreeBuffer (inputBuffer);
+			if (InputBuffer != null)
+				FreeBuffer (InputBuffer);
 		}
 
 		public void SetBuffer (byte [] buffer, int length)
 		{
-			inputBuffer = buffer;
+			InputBuffer = buffer;
 			inputLength = length;
-			gotSomeInput = (length > 0);
+			GotSomeInput = (length > 0);
 			position = 0;
 		}
 
 		void FillBuffer ()
 		{
 			position = 0;
-			inputBuffer = AllocateBuffer ();
-			inputLength = stream.Read (inputBuffer, 0, BSize);
+			InputBuffer = AllocateBuffer ();
+			inputLength = stream.Read (InputBuffer, 0, B_SIZE);
 			if (inputLength == 0) // Socket closed
 				throw new IOException ("socket closed");
 
-			gotSomeInput = true;
+			GotSomeInput = true;
 		}
 
 		string ReadRequestLine ()
 		{
-			StringBuilder text = new StringBuilder ();
-			bool cr = false;
+			var text = new StringBuilder ();
 			do {
-				if (inputBuffer == null || position >= inputLength)
+				if (InputBuffer == null || position >= inputLength)
 					FillBuffer ();
 
 				if (position >= inputLength)
 					break;
 				
-				cr = false;
+				bool cr = false;
 				int count = 0;
 				byte b = 0;
 				int i;
 				for (i = position; count < 8192 && i < inputLength; i++, count++) {
-					b = inputBuffer [i];
+					b = InputBuffer [i];
 					if (b == '\r') {
 						cr = true;
 						count--;
 						continue;
-					} else if (b == '\n' || cr) {
+					}
+					if (b == '\n' || cr) {
 						count--;
 						break;
 					}
@@ -144,15 +153,15 @@ namespace Mono.WebServer
 					break;
 				}
 
-				text.Append (encoding.GetString (inputBuffer, position, count));
+				text.Append (encoding.GetString (InputBuffer, position, count));
 				position = i + 1;
 
 				if (i >= inputLength) {
-					b = inputBuffer [inputLength - 1];
+					b = InputBuffer [inputLength - 1];
 					if (b != '\r' && b != '\n')
 						continue;
 					FillBuffer();
-					if (b == '\r' && inputLength > 0 && inputBuffer[0] == '\n')
+					if (b == '\r' && inputLength > 0 && InputBuffer[0] == '\n')
 						position++;
 				}
 				break;
@@ -167,22 +176,22 @@ namespace Mono.WebServer
 
 		bool GetRequestLine ()
 		{
-			string req = null;
+			string req;
 			try {
 				while (true) {
 					req = ReadRequestLine ();
 					if (req == null) {
-						gotSomeInput = false;
+						GotSomeInput = false;
 						return false;
 					}
 
 					req = req.Trim ();
 					// Ignore empty lines before the actual request.
-					if (req != "")
+					if (req.Length > 0)
 						break;
 				}
 			} catch (Exception) {
-				gotSomeInput = false;
+				GotSomeInput = false;
 				return false;
 			}
 
@@ -217,11 +226,9 @@ namespace Mono.WebServer
 			return true;
 		}
 
-		string GetSafePath (string path)
+		static string GetSafePath (string path)
 		{
-			string trail = "";
-			if (path.EndsWith ("/"))
-				trail = "/";
+			bool appendSlash = path.EndsWith ("/");
 
 			path = HttpUtility.UrlDecode (path);
 			path = path.Replace ('\\','/');
@@ -229,12 +236,12 @@ namespace Mono.WebServer
 				path = path.Replace ("//", "/");
 
 			string [] parts = path.Split ('/');
-			ArrayList result = new ArrayList (parts.Length);
+			var result = new List<string> (parts.Length);
 			
 			int end = parts.Length;
 			for (int i = 0; i < end; i++) {
 				string current = parts [i];
-				if (current == "" || current == "." )
+				if (current.Length == 0 || current == "." )
 					continue;
 
 				if (current == "..") {
@@ -249,8 +256,15 @@ namespace Mono.WebServer
 			if (result.Count == 0)
 				return "/";
 
-			result.Insert (0, "");
-			return String.Join ("/", (string []) result.ToArray (typeof (string))) + trail;
+			var res = new StringBuilder();
+			foreach (var part in result) {
+				res.Append ('/');
+				res.Append (part);
+			}
+
+			if (appendSlash)
+				res.Append ('/');
+			return res.ToString ();
 		}
 		
 		public void ReadRequestData ()
@@ -262,24 +276,6 @@ namespace Mono.WebServer
 				protocol = "HTTP/1.0";
 			}
 		}
-
-		public bool GotSomeInput {
-			get { return gotSomeInput; }
-		}
-
-		public byte [] InputBuffer {
-			get { return inputBuffer; }
-		}
-
-		public RequestData RequestData {
-			get {
-				RequestData rd = new RequestData (verb, path, queryString, protocol);
-				byte [] buffer = new byte [inputLength - position];
-				Buffer.BlockCopy (inputBuffer, position, buffer, 0, inputLength - position);
-				rd.InputBuffer = buffer;
-				return rd;
-			}
-		}
 	}
 }
 
