@@ -27,13 +27,6 @@
 // WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 //
 using System;
-using System.Collections;
-using System.Configuration;
-using System.IO;
-using System.Net;
-using System.Net.Sockets;
-using System.Text;
-using System.Web;
 
 namespace Mono.WebServer
 {
