@@ -15,7 +15,20 @@ public class Populate: Page
 
         for (int n = 0; n < (e.Node.Depth+1) * 2; n++)
         {
-            TreeNode nod = new TreeNode("Node " + e.Node.Depth + " " + n);
+			string label = string.Empty;
+			if (e.Node.Depth < 1) 
+				label = "Node";
+			else
+				label = e.Node.Text;
+	
+			if (Char.IsDigit(label.ToCharArray()[label.Length-1])) {
+				label += " " + (char)(n + 65);
+			} else {
+				label += " " + n;
+
+			}
+			TreeNode nod = new TreeNode(label);
+            //TreeNode nod = new TreeNode("Node " + e.Node.Depth + " " + n);
             nod.PopulateOnDemand = true;
             e.Node.ChildNodes.Add(nod);
         }
